<!DOCTYPE kpartgui >
<kpartgui version="3" name="keducaTestMaster" >
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="open_gallery"/>
  </Menu>
  <Merge/>
</MenuBar>
</kpartgui>
