<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kmplot_shell" version="1">
	<MenuBar>
		<Menu noMerge="1" name="file"><text>&amp;File</text>
			<Action name="file_new"/>
			<Separator/>
			<Action name="file_open"/>
			<Merge/>
			<Separator/>
			<Action name="file_quit"/>
		</Menu>
		<Merge/>
		<Menu noMerge="1" name="settings"><text>&amp;Settings</text>
			<!--<Action name="options_show_toolbar"/>-->
			<Merge name="StandardToolBarMenuHandler" />
			<Action name="options_show_statusbar"/>
			<Separator/>
			<Action name="fullscreen" />
			<Merge/>
<!--			<Separator/>
			<Action name="options_configure_keybinding"/>
			<Action name="options_configure_toolbars"/>
			<Action name="options_configure"/>-->
			<Separator/>
		</Menu>
		<Menu name="help" noMerge="1"><text>&amp;Help</text>
			<Action name="help_contents"/>
			<Action name="help_whats_this"/>
			<Separator/>
			<Merge/>
			<Separator/>
			<Action name="help_report_bug"/>
			<Separator/>
			<Action name="help_about_app"/>
			<Action name="help_about_kde"/>
		</Menu>
	</MenuBar>
	<ToolBar noMerge="1" name="mainToolBar"><text>Main Toolbar</text>
		<Action name="file_new"/>
		<Action name="file_open"/>
		<Merge/>
	</ToolBar>
</kpartgui>