<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="Kiten Learn" version="3">

<MenuBar>
<Menu name="file" noMerge="1"><text>&amp;File</text>
  <Action name="file_new"/>
  <Action name="file_open"/>
  <Separator/>
  <Action name="file_save"/>
  <Action name="file_save_as"/>
  <Separator/>
  <Action name="file_print"/>
  <Separator/>
  <Action name="file_close"/>
</Menu>

<Menu name="edit">
  <Action name="add" />
  <Action name="addall" />
  <Action name="del" />
</Menu>

<Menu name="go_web">
  <Action name="grade" />
  <Action name="random" />
  <Action name="cheat" />
</Menu>

</MenuBar>

<ToolBar name="mainToolBar" fullWidth="true"><text>Main Toolbar</text>
  <Action name="go_back" />
  <Action name="go_forward" />
  <Action name="random" />
  <Separator />
  <Action name="add" />
  <Action name="del" />
  <Separator />
  <Action name="grade" />
</ToolBar>

</kpartgui>
