<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kturtle" version="2" >
<MenuBar>
    <Menu name="file" noMerge="1"><text>&amp;File</text>
      <Action name="file_new" />
      <Action name="file_open" />
      <Action name="file_open_recent" />
      <Action name="open_examples" />
      <Separator />
      <Action name="file_save" />
      <Action name="file_save_as" />
      <Action name="save_canvas" />
      <Separator />
      <Action name="speed" />
      <Action name="run" />
      <Action name="pause" />
      <Action name="stop" />
      <Separator />
      <Action name="file_print" />
      <Separator />
      <Action name="file_quit" />
    </Menu>
   
    <Menu name="edit" noMerge="1"><text>&amp;Edit</text>
      <Action name="edit_undo" />
      <Action name="edit_redo" />
      <Separator />
      <Action name="edit_cut" />
      <Action name="edit_copy" />
      <Action name="edit_paste" />
      <Separator />
      <Action name="edit_find" />
      <Action name="edit_find_next" />
      <Action name="edit_replace" />
    </Menu>
    
    <Menu name="view" noMerge="1"><text>&amp;View</text>
      <Action name="full_screen" />
      <Separator />
      <Action name="line_numbers" />
    </Menu>
    
    <Menu name="tools" noMerge="1"><text>&amp;Tools</text>
      <Action name="color_picker" />
      <Separator />
      <Action name="edit_indent" />
      <Action name="edit_unindent" />
      <Action name="edit_cleanIndent" />
      <Separator />
      <Action name="edit_comment" />
      <Action name="edit_uncomment" />
    </Menu>
    
     <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
       <Merge name="StandardToolBarMenuHandler" />
       <Action name="options_show_statusbar"/>
       <Separator />
       <Menu name="Advanced settings"><text>&amp;Advanced Settings</text>
          <Action name="set_confdlg" />
          <Action name="options_configure_keybinding"/>
          <Action name="options_configure_toolbars"/>
       </Menu>
       <Action name="options_configure"/>
     </Menu>
    
    <Menu name="help"><text>&amp;Help</text>
      <Action name="context_help" />
    </Menu>
  </MenuBar>

<ToolBar name="mainToolBar" noMerge="1" fullWidth="true" >
  <Action name="file_new" />
  <Action name="file_open" />
  <Separator />
  <Action name="file_save" />
  <Action name="file_save_as" />
  <Separator />
  <Action name="file_print" />
  <Separator />
  <Action name="edit_undo" />
  <Action name="edit_redo" />
  <Separator />
  <Action name="edit_cut" />
  <Action name="edit_copy" />
  <Action name="edit_paste" />
  <Separator />
  <Action name="color_picker" />
  <Separator />
  <Action name="full_screen" />
  <Separator />
  <Action name="speed" />
  <Action name="run" />
  <Action name="pause" />
  <Action name="stop" />
</ToolBar>

</kpartgui>
