<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="ktouch" version="1.5.3">
<MenuBar>
  <Menu name="file"><text>F&amp;ile</text>
    <Action name="file_openlecture" />
    <Action name="file_editlecture" />
    <Separator/>
    <Action name="file_editcolors" />
    <Action name="file_editkeyboard" />
  </Menu>
  <Menu name="training"><text>T&amp;raining</text>
    <Action name="training_newsession" />
    <Action name="training_pause" />
    <Separator/>
    <Action name="training_stats" />
    <Action name="default_lectures" />
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="keyboard_layouts" append="save_merge"/>
    <Action name="keyboard_schemes" append="save_merge"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar"><text>Main Toolbar</text>
  <Action name="training_newsession" />
  <Action name="training_pause" />
  <Separator/>
  <Action name="training_stats" />
</ToolBar>
</kpartgui>
