<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kgeography" version="1">
	<MenuBar>
		<Menu name="file">
			<Action name="openMap" />
			<Separator />
			<Action name="quit" />
		</Menu>
		<Menu name="view">
			<Action name="zoom_select" />
			<Action name="zoom_original" />
			<Separator />
			<Action name="move" />
		</Menu>
		<Menu name="help">
			<Action name="disclaimer"/>
		</Menu>
	</MenuBar>
	<ToolBar name="mainToolBar">
		<Action name="zoom_select" />
		<Action name="zoom_original" />
		<Separator />
		<Action name="move" />
	</ToolBar>
</kpartgui>
