<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kbruch" version="1">
<MenuBar>
  <Menu noMerge="1" name="file"><text>&amp;Task</text>
    <Action name="NewTask"/>
    <Merge/>
    <Separator/>
    <Action name="file_quit"/>
  </Menu>
</MenuBar>
<ToolBar noMerge="1" name="mainToolBar" fullWidth="true">
  <text>Main Toolbar</text>
  <Action name="NewTask"/>
  <Separator/>

  <Action name="NrOfTermsLabelAction"/>
  <Action name="NrOfTermsBoxAction"/>

  <Separator/>

  <Action name="MaxMainDenominatorLabelAction"/>
  <Action name="MaxMainDenominatorBoxAction"/>

  <Separator/>

  <Action name="OperationLabelAction"/>
  <Action name="OperationBoxAction"/>

  <Action name="help"/>
</ToolBar>
</kpartgui>
