<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kig_part" version="10">
  <MenuBar>
    <Menu name="file">
      <text>&amp;File</text>
      <Action name="file_save" />
      <Action name="file_save_as" />
      <Separator />
      <Action name="file_print" />
      <Action name="file_print_preview" />
      <Separator />
      <Action name="file_export" />
      <Separator />
    </Menu>
    <Menu name="edit">
      <text>&amp;Edit</text>
      <Action name="edit_undo" />
      <Action name="edit_redo" />
      <Separator />
      <Action name="edit_select_all" />
      <Action name="edit_deselect" />
      <Action name="edit_invert_selection" />
      <Separator/>
      <Action name="edit_unhide_all" />
    </Menu>
    <Menu name="view">
      <text>&amp;View</text>
      <Action name="view_zoom_in" />
      <Action name="view_zoom_out" />
      <Action name="view_fit_to_page" />
      <Action name="view_select_shown_rect" />
      <Action name="view_zoom_area" />
    </Menu>
    <Menu name="objects">
      <text>&amp;Objects</text>
      <Menu name="new_point" icon="point">
	<text>&amp;Points</text>
	<Action name="objects_new_normalpoint" />
	<Action name="objects_new_midpoint" />
	<Action name="objects_new_intersection" />
	<Action name="objects_new_point_xy" />
	<Action name="objects_new_translatedpoint" />
	<Action name="objects_new_rotatedpoint" />
	<Action name="objects_new_mirrorpoint" />
	<ActionList name="user_point_types" />
      </Menu>
      <Menu name="new_line" icon="line">
	<text>&amp;Lines</text>
	<Action name="objects_new_linettp" />
	<Action name="objects_new_lineperpend" />
	<Action name="objects_new_lineparallel" />
	<Action name="objects_new_ray" />
	<Action name="objects_new_linebyvector" />
	<Action name="objects_new_halflinebyvector" />
	<ActionList name="user_line_types" />
      </Menu>
      <Menu name="new_circle" icon="circlebps">
	<text>&amp;Circles &amp;&amp; Arcs</text>
	<Action name="objects_new_circlebcp" />
	<Action name="objects_new_circlebtp" />
	<Action name="objects_new_circlebps" />
	<Action name="objects_new_circlebpd" />
	<Action name="objects_new_circlebcl" />
	<Action name="objects_new_arcbtp" />
	<Action name="objects_new_arcbcpa" />
	<ActionList name="user_circle_types" />
      </Menu>
      <Menu name="new_poligon" icon="hexagonbcv">
	<text>Poly&amp;gons</text>
	<Action name="objects_new_trianglebtp" />
	<Action name="objects_new_polygonbnp" />
	<Action name="objects_new_polygonbcv" />
	<Action name="objects_new_equitriangle" />
	<Action name="objects_new_square" />
	<Action name="objects_new_polygonvertices" />
	<Action name="objects_new_polygonsides" />
	<Action name="objects_new_convexhull" />
      </Menu>
      <Menu name="new_vector" icon="vector">
	<text>&amp;Vectors &amp;&amp; Segments</text>
	<Action name="objects_new_segment" />
	<Action name="objects_new_segment_axis" />
	<Action name="objects_new_vector" />
	<Action name="objects_new_vectorsum" />
	<Action name="objects_new_vectordifference" />
	<ActionList name="user_segment_types" />
      </Menu>
      <Menu name="new_conic" icon="conicb5p">
	<text>Co&amp;nics &amp;&amp; Cubics</text>
	<Action name="objects_new_ellipsebffp" />
	<Action name="objects_new_hyperbolabffp" />
	<Action name="objects_new_conicb5p" />
	<Action name="objects_new_parabolabtp" />
	<ActionList name="user_conic_types" />
	<Menu name="new_moreconics" icon="conicsradicalline">
	  <text>More Conics</text>
	  <Action name="objects_new_parabolabdp" />
	  <Action name="objects_new_equilateralhyperbolab4p" />
	  <Action name="objects_new_conicbdfp" />
	  <Action name="objects_new_conicbaap" />
	  <Action name="objects_new_linepolar" />
	  <Action name="objects_new_lineconicasymptotes" />
	  <Action name="objects_new_pointpolar" />
	  <Action name="objects_new_linedirectrix" />
	  <Action name="objects_new_lineconicradical" />
        </Menu>
        <Separator />
        <Menu name="new_cubic">
	  <text>Cu&amp;bics</text>
	  <Action name="objects_new_cubicb9p" />
	  <Action name="objects_new_cubicnodeb6p" />
	  <Action name="objects_new_cubiccuspb4p" />
        </Menu>
      </Menu>
      <Menu name="new_angle" icon="angle">
	<text>&amp;Angles</text>
	<Action name="objects_new_angle" />
	<Action name="objects_new_angle_bisector" />
      </Menu>
      <Menu name="new_transformation" icon="centralsymmetry">
	<text>&amp;Transformations</text>
	<Action name="objects_new_translation" />
	<Action name="objects_new_pointreflection" />
	<Action name="objects_new_linereflection" />
	<Action name="objects_new_rotation" />
	<Action name="objects_new_scalingovercenter" />
	<Action name="objects_new_scalingovercenter2" />
	<Action name="objects_new_scalingoverline" />
	<Action name="objects_new_scalingoverline2" />
	<Action name="objects_new_similitude" />
	<Action name="objects_new_inversion" />
	<Action name="objects_new_harmonichomology" />
	<Action name="objects_new_genericaffinity" />
	<Action name="objects_new_genericprojectivity" />
	<Action name="objects_new_castshadow" />
	<Action name="objects_new_projectiverotation" />
      </Menu>
      <Menu name="new_differentialgeometry" icon="tangent">
	<text>&amp;Differential geometry</text>
	<Action name="objects_new_tangent" />
	<Action name="objects_new_centerofcurvature" />
	<Action name="objects_new_osculatingcircle" />
	<Action name="objects_new_evolute" />
      </Menu>
      <Menu name="new_test" icon="test">
	<text>T&amp;ests</text>
	<Action name="objects_new_areparallel" />
	<Action name="objects_new_areorthogonal" />
	<Action name="objects_new_arecollinear" />
	<Action name="objects_new_containstest" />
	<Action name="objects_new_distancetest" />
	<Action name="objects_new_vectorequalitytest" />
	<Action name="objects_new_inpolygontest" />
	<Action name="objects_new_convexpolygontest" />
      </Menu>
      <Menu name="new_other">
	<text>&amp;Other</text>
	<Action name="objects_new_locus" />
	<Action name="objects_new_textlabel" />
	<Action name="objects_new_measuretransport" />
	<Action name="objects_new_script_python" />
	<ActionList name="user_other_types" />
      </Menu>
      <Separator />
      <Action name="delete_objects" />
      <Action name="cancel_construction" />
    </Menu>
    <Menu name="types">
      <text>&amp;Types</text>
      <Action name="macro_action" />
      <Action name="types_edit" />
    </Menu>
    <Menu name="settings">
      <Action name="fullscreen" />
      <Action name="settings_set_coordinate_system" />
      <Action name="settings_show_grid" />
      <Action name="settings_show_axes" />
      <Action name="settings_toggle_nightvision" />
    </Menu>
  </MenuBar>
  <ToolBar name="mainToolBar">
    <text>Main Toolbar</text>
    <Action name="file_save" />
    <Action name="file_save_as" />
    <Separator />
    <Action name="file_print" />
    <Separator />
    <Action name="edit_undo"/>
    <Action name="edit_redo"/>
    <Separator />
    <Action name="delete_objects"/>
    <Action name="cancel_construction"/>
    <Action name="macro_action"/>
  </ToolBar>
  <ToolBar name="points_toolbar" position="left">
    <text>Points</text>
    <Action name="objects_new_normalpoint" />
    <Action name="objects_new_point_xy" />
    <Action name="objects_new_intersection" />
    <Action name="objects_new_midpoint" />
    <Action name="objects_new_mirrorpoint" />
    <Action name="objects_new_rotatedpoint" />
    <Action name="objects_new_translatedpoint" />
    <ActionList name="user_point_types" />
  </ToolBar>
  <ToolBar name="line_toolbar" position="left">
    <text>Lines</text>
    <Action name="objects_new_linettp" />
    <Action name="objects_new_ray" />
    <Action name="objects_new_lineperpend" />
    <Action name="objects_new_lineparallel" />
    <Action name="objects_new_linebyvector" />
    <Action name="objects_new_halflinebyvector" />
    <ActionList name="user_line_types" />
  </ToolBar>
  <ToolBar name="vectseg_toolbar" position="left">
    <text>Vectors &amp;&amp; Segments</text>
    <Action name="objects_new_segment" />
    <Action name="objects_new_segment_axis" />
    <Action name="objects_new_vector" />
    <Action name="objects_new_vectorsum" />
    <ActionList name="user_segment_types" />
  </ToolBar>
  <ToolBar name="circle_toolbar" position="left">
    <text>Circles &amp;&amp; Arcs</text>
    <Action name="objects_new_circlebcp" />
    <Action name="objects_new_circlebtp" />
    <Action name="objects_new_circlebps" />
    <Action name="objects_new_circlebpd" />
    <Action name="objects_new_arcbtp" />
    <ActionList name="user_circle_types" />
  </ToolBar>
  <ToolBar name="conic_toolbar" position="left">
    <text>Conics</text>
    <Action name="objects_new_ellipsebffp" />
    <Action name="objects_new_hyperbolabffp" />
    <Action name="objects_new_parabolabtp" />
    <Action name="objects_new_conicb5p" />
    <ActionList name="user_conic_types" />
    <Action name="objects_new_lineconicradical" />
  </ToolBar>
  <ToolBar name="angles_toolbar" position="left">
    <text>Angles</text>
    <Action name="objects_new_angle" />
    <Action name="objects_new_angle_bisector" />
  </ToolBar>
  <ToolBar name="transformation_toolbar" position="right">
    <text>Transformations</text>
    <Action name="objects_new_translation" />
    <Action name="objects_new_pointreflection" />
    <Action name="objects_new_linereflection" />
    <Action name="objects_new_rotation" />
    <Action name="objects_new_scalingovercenter" />
    <Action name="objects_new_scalingoverline" />
    <Action name="objects_new_similitude" />
    <Action name="objects_new_inversion" />
    <Action name="objects_new_harmonichomology" />
    <Action name="objects_new_genericaffinity" />
    <Action name="objects_new_genericprojectivity" />
  </ToolBar>
  <ToolBar name="tests_toolbar" position="right">
    <text>Tests</text>
    <Action name="objects_new_areparallel" />
    <Action name="objects_new_areorthogonal" />
    <Action name="objects_new_arecollinear" />
    <Action name="objects_new_containstest" />
    <Action name="objects_new_distancetest" />
    <Action name="objects_new_vectorequalitytest" />
    <Action name="objects_new_inpolygontest" />
    <Action name="objects_new_convexpolygontest" />
  </ToolBar>
  <ToolBar name="rest_toolbar" position="left">
    <text>Other Objects</text>
    <Action name="objects_new_locus" />
    <Action name="objects_new_textlabel" />
    <Action name="objects_new_script_python" />
    <ActionList name="user_other_types" />
  </ToolBar>
  <ToolBar name="view_toolbar">
    <text>View</text>
    <Action name="view_zoom_in" />
    <Action name="view_zoom_out" />
    <Action name="fullscreen" />
    <Action name="view_fit_to_page" />
    <Action name="view_select_shown_rect" />
    <Action name="view_zoom_area" />
  </ToolBar>
</kpartgui>
