<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">

<kpartgui name="KStars" version="2">
<MenuBar noMerge="1">
	<Menu name="file" noMerge="1"><text>&amp;File</text>
		<Action name="new_window" />
		<Action name="close_window" />
		<Separator />
		<Action name="get_data" />
		<Separator />
		<Action name="open_file" />
		<Action name="export_image" />
		<Action name="run_script" />
		<Separator />
		<Action name="print" />
		<Separator />
		<Action name="quit"/>
	</Menu>

	<Menu name="time" noMerge="1"><text>T&amp;ime</text>
		<Action name="time_to_now" />
		<Action name="time_dialog" />
		<Separator />
		<Action name="timer_control" />
	</Menu>

	<Menu name="focus" noMerge="1"><text>&amp;Pointing</text>
		<Action name="zenith" />
		<Action name="north" />
		<Action name="east" />
		<Action name="south" />
		<Action name="west" />
		<Separator />
		<Action name="manual_focus" />
		<Separator />
		<Action name="find_object" />
		<Action name="track_object" />
	</Menu>

	<Menu name="view" noMerge="1"><text>&amp;View</text>
		<Action name="zoom_in" />
		<Action name="zoom_out" />
		<Action name="zoom_default" />
		<Action name="zoom_set" />
		<Separator />
		<Action name="fullscreen" />
		<Separator />
		<Action name="coordsys" />
	</Menu>

	<Menu name="devices" noMerge="1"><text>&amp;Devices</text>
		<Action name="telescope_wizard" />
		<Action name="telescope_properties" />
		<Action name="device_manager" />
		
		<Separator />
		<Action name="indi_control_panel" />
		<Action name="capture_sequence" />
		<Separator />
		<Action name="configure_indi" />

	</Menu>

	<Menu name="tools" noMerge="1"><text>&amp;Tools</text>
		<Action name="astrocalculator" />
		<Action name="obslist" />
		<Action name="lightcurvegenerator" />
		<Action name="altitude_vs_time" />
		<Action name="whats_up_tonight" />
<!--FIXME GLOSSARY
		<Action name="glossary" />
-->
		<Action name="scriptbuilder" />
		<Action name="solarsystem" />
		<Action name="jmoontool" />
	</Menu>

	<Menu name="settings" noMerge="1"><text>&amp;Settings</text>
		<Menu name="infopanel"><text>&amp;Info Boxes</text>
			<Action name="show_boxes"/>
			<Separator />
			<Action name="show_time_box" />
			<Action name="show_focus_box" />
			<Action name="show_location_box" />
		</Menu>
		<Menu name="toolbars"><text>&amp;Toolbars</text>
			<Action name="show_mainToolBar" />
			<Action name="show_viewToolBar" />
		</Menu>
		<Menu name="statusbar"><text>&amp;Statusbar</text>
			<Action name="show_statusBar" />
			<Separator />
			<Action name="show_sbAzAlt" />
			<Action name="show_sbRADec" />
		</Menu>
		<Action name="colorschemes" /> <!--This is a KMenuAction-->
		<Action name="fovsymbols" /> <!-- This is a KMenuAction-->
		<Separator />
		<Action name="geolocation" />
		<Separator />
		<Action name="configure" />
		<Action name="startwizard" />
	</Menu>

	<Menu name="help"><text>&amp;Help</text>
		<Action name="help_contents"/>
		<Action name="help_tipofday"/>
		<Separator/>
		<Action name="help_report_bug"/>
		<Separator/>
		<Action name="help_about_app"/>
		<Action name="help_about_kde"/>
	</Menu>
</MenuBar>

<ToolBar noMerge="1" name="mainToolBar"><text>Main Toolbar</text>
	<Action name="fullscreen" />
	<Action name="zoom_in" />
	<Action name="zoom_out" />
	<Action name="zoom_default" />
	<Action name="track_object" />
	<Separator />
	<Action name="find_object" />
	<Action name="geolocation" />
	<Action name="time_dialog" />
	<Separator />
	<Action name="timer_control" />
	<Separator />
</ToolBar>

<ToolBar noMerge="1" name="viewToolBar"><text>View Toolbar</text>
	<Action name="show_stars" />
	<Action name="show_deepsky" />
	<Action name="show_planets" />
	<Action name="show_clines" />
	<Action name="show_cnames" />
	<Action name="show_cbounds" />
	<Action name="show_mw" />
	<Action name="show_grid" />
	<Action name="show_horizon" />
</ToolBar>
</kpartgui>
