<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="FitsViewer" version="3">

<Menu name="file"><text>&amp;File</text>
		<Action name="file_open" />
		<Action name="file_save"/>
		<Action name="file_save_as"/>
		<Separator/>
		<Action name="close"/>
</Menu>

<Menu name="edit"><text>&amp;Edit</text>
		<Action name="edit_undo"/>
		<Action name="edit_redo"/>
		<Separator/>
		<Action name="edit_copy"/>
</Menu>

<Menu name="view"><text>&amp;View</text>
		<Action name="view_zoom_in"/>
		<Action name="view_zoom_out"/>
		<Action name="zoom_default"/>
</Menu>

<ToolBar noMerge="1" name="mainToolBar"><text>Main Toolbar</text>
	<Action name="file_open" />
        <Action name="file_save" />
	<Action name="file_save_as" />
	<Action name="edit_undo" />
	<Action name="edit_redo" />
	<Action name="view_zoom_in" />
	<Action name="view_zoom_out" />	
	<Action name="zoom_default"/>
</ToolBar>
	
<ToolBar noMerge="1" name="processToolBar"><text>Process ToolBar</text>
	<Action name="image_brightness_contrast" />
	<Action name="image_histogram" />
	<Action name="image_stats" />
	<Action name="fits_editor" />
	<Action name="image_reduce" />
</ToolBar>
</kpartgui>
