<!DOCTYPE kpartgui >
<kpartgui version="2" name="keducaEditor" >
<MenuBar>
	<Menu name="file"><text>&amp;File</text>
    <Action name="open_gallery"/>
    <Action name="info_doc"/>
	</Menu>
	<Menu name="Edit" ><text>&amp;Edit</text>
		<Action name="question_add" />
		<Action name="question_edit" />
		<Action name="question_remove" />
		<Separator lineSeparator="true"/>
		<Action name="question_up" icon="up"/>
		<Action name="question_down" icon="down"/>
	</Menu>
</MenuBar>
<ToolBar name="mainToolBar" >
	<Action name="info_doc" />
</ToolBar>
<ToolBar name="mainQuestionBar" >
	<Action name="question_add" />
	<Action name="question_edit" />
	<Action name="question_remove" />
	<Separator lineSeparator="true"/>
	<Action name="question_up" icon="up"/>
	<Action name="question_down" icon="down"/>
</ToolBar>
</kpartgui>
