<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="klatin" version="3">
<MenuBar>

	<Menu name="section" noMerge="1"><text>S&amp;ection</text>
		<Action name="go_vocab" />
		<Action name="go_grammar" />
		<Action name="go_verbs" />
		<Action name="go_revision" />
	</Menu>
</MenuBar>
</kpartgui>
